==> haskell-persistent-test-2.13.1.3-197.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-97sBgoR1qpdIf1PZLQklWW
key:                  persistent-test-2.13.1.3-97sBgoR1qpdIf1PZLQklWW
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  573876f8e3d8cc58bf1cc91279a47813
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-97sBgoR1qpdIf1PZLQklWW
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q containers-0.6.7
    exceptions-0.10.7 hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
    hspec-expectations-0.8.4-7xRGbz7YGlh8mVR0kjpKwh
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-logger-0.3.42-4mR0wENhtiT2BdGv1Hn8yK mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-LW4wp3jmP881UTaaXowY4R
    quickcheck-instances-0.3.33-HOHYeHmWAjz1SmrXgJcTlH
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2 time-1.12.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.13.1.3-198-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-qryy0yifAW2cTFo45m6iC
key:                  persistent-test-2.13.1.3-qryy0yifAW2cTFo45m6iC
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  bad70115ecc7355cf677141a93363234
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-qryy0yifAW2cTFo45m6iC
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q containers-0.6.7
    exceptions-0.10.7 hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
    hspec-expectations-0.8.4-7xRGbz7YGlh8mVR0kjpKwh
    http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-logger-0.3.42-8CskNFmll7427ag5mqbmhY mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-GJyCnJ8J8PvBVRSOBxUsv4
    quickcheck-instances-0.3.33-HOHYeHmWAjz1SmrXgJcTlH
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2 time-1.12.2
    transformers-0.6.1.0 transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
